"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireDefault(require("react"));

var _jsYaml = _interopRequireDefault(require("js-yaml"));

var _YamlInput = _interopRequireDefault(require("./YamlInput"));

var __jsx = _react["default"].createElement;

var useErrors = function useErrors(onError) {
  var _React$useState = _react["default"].useState(null),
      _React$useState2 = (0, _slicedToArray2["default"])(_React$useState, 2),
      error = _React$useState2[0],
      setError = _React$useState2[1];

  var cleanErrors = function cleanErrors() {
    return setError(null);
  };

  var markError = function markError(_ref) {
    var position = _ref.position,
        message = _ref.message,
        snippet = _ref.snippet;
    setError({
      position: position,
      message: message,
      snippet: snippet
    });
    onError(true);
  };

  return {
    cleanErrors: cleanErrors,
    errorRanges: error,
    markError: markError,
    hasErrors: !!error,
    error: error
  };
};

var YamlEditor = function YamlEditor(_ref2) {
  var json = _ref2.json,
      text = _ref2.text,
      theme = _ref2.theme,
      _ref2$onError = _ref2.onError,
      onError = _ref2$onError === void 0 ? function () {} : _ref2$onError,
      _ref2$onChange = _ref2.onChange,
      onChange = _ref2$onChange === void 0 ? function () {} : _ref2$onChange;
  var errors = useErrors(onError);
  var textValue = json ? _jsYaml["default"].dump(json) : text;

  var currentText = _react["default"].useRef(textValue); // const [currentText, setCurrentText] = React.useState(textValue);


  var handleChange = function handleChange(newText) {
    try {
      currentText.current = newText;

      var newJson = _jsYaml["default"].load(newText);

      if (errors.hasErrors) {
        errors.cleanErrors();
        onError(null);
      }

      onChange({
        json: newJson,
        text: newText
      });
    } catch (err) {
      var _err$mark;

      onError(err);

      if (!((_err$mark = err.mark) !== null && _err$mark !== void 0 && _err$mark.snippet)) {
        console.error(err);
        return;
      }

      console.error(err.mark.snippet);
      errors.markError({
        position: err.mark.position,
        message: err.message,
        snippet: err.mark.snippet
      });
    }
  };

  var getErrorPos = function getErrorPos(newText) {
    try {
      _jsYaml["default"].load(newText);

      return {};
    } catch (err) {
      var _err$mark2;

      if (!((_err$mark2 = err.mark) !== null && _err$mark2 !== void 0 && _err$mark2.snippet)) {
        return {};
      }

      return {
        position: err.mark.position
      };
    }
  };

  return __jsx(_YamlInput["default"], {
    value: currentText.current,
    onChange: handleChange,
    error: errors.error,
    getErrorPos: getErrorPos,
    options: {
      handleTabs: true,
      theme: theme
    }
  });
};

var _default = YamlEditor;
exports["default"] = _default;